@@ -110,7 +110,7 @@ class TaskTreeNode(object):
         return tasks
 
 
-def task_with_callbacks(func):
+def task_with_callbacks(func, **options):
     """ decorator "task with callbacks"
 
     Callback or list of callbacks which go to function in "callbacks" kwarg,
@@ -121,6 +121,16 @@ def task_with_callbacks(func):
     "async_result" will be added to that object so that it will be possible to
     join() for that result.
     """
+    return task(run_with_callbacks(func), **options)
+
+
+def run_with_callbacks(func):
+    """Decorator "run with callbacks"
+
+    Function is useful as decorator for :meth:`run` method of tasks which are
+    subclasses of generic :class:`celery.task.Task` and are expected to be used
+    with callbacks.
+    """
     @wraps(func)
     def wrapper(*args, **kwargs):
         callback = kwargs.pop('callback', None)
@@ -131,7 +141,7 @@ def task_with_callbacks(func):
         except AttributeError:
             pass
         return retval
-    return task(wrapper)
+    return wrapper
 
 
 def _exec_callbacks(callback):
